fnss.traffic.eventscheduling.EventSchedule.add — FNSS 0.7.0 documentation

# fnss.traffic.eventscheduling.EventSchedule.add

`EventSchedule.` `add`(time, event, absolute_time=False)

  Adds an event to the schedule.

  Events are inserted so that the schedule is always chronologically sorted.

  Parameters: | time : float The time at which the event takes place event : dict The properties of the event absolute_time : bool, optional Specifies whether the time is expressed as absolute time or as interval from the latest event of the schedule